Attribute VB_Name = "modStringFunctions"
'  modStringFunctions.bas
'  Module that allows easy string manipulation and parsing
'  Written by: Delphy (delphy@hwcommunity.com)
'
'  ---------------------------------------------------
'  DO NOT MAKE CHANGES TO THIS FILE - CONSULT ME FIRST
'  ---------------------------------------------------

Option Explicit

' White Space Characters
Public Const ascSpace As Byte = 32
Public Const ascTab As Byte = 9

Function getWord(inputString As String, wordToGet As Integer, Optional seperator As Byte) As String

  ' This function gets a particular "word" in a string
  ' seperated by spaces.
  ' Example: getWord("Hello", 1) returns "Hello"
  '          getWord("Hello", 2) returns "" (out of range)
  '          getWord("Hello There", 2) returns "There"
  ' Note that spaces are automatically stripped off

  If seperator = 0 Then seperator = ascSpace

  Dim currentWord As Integer
  Dim cwStart As Integer
  Dim tmpString As String
  tmpString = inputString
  
  If wordToGet = -1 Then Exit Function
  Do
    currentWord = currentWord + 1
    cwStart = getFirstSepPos(tmpString, seperator)
    'If seperator <> 32 Then
    '  Debug.Print currentWord & " : " & wordToGet & " - " & cwStart, tmpString
    'End If
    If cwStart = 0 Then
      If currentWord < wordToGet Then
        getWord = ""
        Exit Do
      Else
        getWord = tmpString
      End If
    Else
      getWord = Mid$(tmpString, 1, cwStart - 1)
      If Right(getWord, 1) = "," Then
        getWord = Left(getWord, Len(getWord) - 1)
      End If
      tmpString = stripLeading(Mid$(tmpString, cwStart), seperator)
    End If
  Loop Until currentWord = wordToGet
  
End Function

Function stripLeading(inputString As String, Optional seperator As Byte) As String
  
  If seperator = 0 Then seperator = ascSpace
  
  ' This function strips leading spaces and tabs from
  ' an input string - Trim only removes spaces :(
  Dim i As Integer
  For i = 1 To Len(inputString)
    'If (Mid$(inputString, i, 1) <> Chr$(ascSpace) And Mid$(inputString, i, 1) <> Chr$(ascTab)) And Mid$(inputString, i, 1) <> Chr$(seperator) Then Exit For
    If Mid$(inputString, i, 1) <> Chr$(seperator) Then Exit For
  Next i
  stripLeading = Mid$(inputString, i)

End Function

Function getFirstSepPos(inputString As String, Optional seperator As Byte) As Integer
  
  If seperator = 0 Then seperator = ascSpace
  
  Dim spcPos As Integer, tabPos As Integer
  
  spcPos = InStr(inputString, Chr$(seperator))
  tabPos = InStr(inputString, Chr$(ascTab))
  If spcPos = 0 And tabPos = 0 Then
    getFirstSepPos = 0
    Exit Function
  End If
  If spcPos = 0 Then spcPos = 32767
  If tabPos = 0 Then tabPos = 32767
  
  If spcPos < tabPos Then
    getFirstSepPos = spcPos
  Else
    getFirstSepPos = tabPos
  End If
  
End Function

Function countTokens(inputString As String, searchString As String) As Integer
  
  Dim lngPos As Integer
  Dim lngCount As Integer

  If Len(inputString) > 0 Then
    lngPos = 1
    Do
      lngPos = InStr(lngPos, inputString, searchString)
      If lngPos > 0 Then
        lngCount = lngCount + 1
        lngPos = lngPos + Len(searchString)
      End If
    Loop While lngPos > 0
    countTokens = lngCount + 1
  Else
    countTokens = 0
  End If

End Function

Function stripBrackets(inputString As String) As String
  
  ' Returns a string with all brackets stripped
  ' ie label(hello) returns "label hello"
  inputString = Replace(inputString, "(", " ")
  inputString = Replace(inputString, ")", " ")
  inputString = Replace(inputString, "[", " ")
  inputString = Replace(inputString, "]", " ")
  inputString = Replace(inputString, "{", " ")
  inputString = Replace(inputString, "}", " ")
  stripBrackets = inputString

End Function

Function stripChar(inputString As String, charToStrip As String) As String
  inputString = Replace(inputString, charToStrip, " ")
  stripChar = inputString
End Function

' Returns a string of characters ready to write to a file
' (with leading zeros on the hex number if need be)
Function writeHex(hexString As String, stringLength As Integer)
  
  Dim i As Integer
  Dim temp As String

  stringLength = stringLength * 2
  If Len(hexString) < stringLength Then
    hexString = String(stringLength - Len(hexString), "0") & hexString
  End If
  Do While (Len(hexString) Mod 2) = 1
    hexString = "0" & hexString
  Loop
  For i = 1 To Len(hexString) Step 2
    'temp = temp & Chr$(Base2Long(Mid$(hexString, i, 2), 16))
  Next i
  writeHex = temp

End Function
' Same as previous function except reverses the string
' first
Function writeHexR(hexString As String, stringLength As Integer)
  
  Dim i As Integer
  Dim temp As String

  stringLength = stringLength * 2
  If Len(hexString) < stringLength Then
    hexString = String(stringLength - Len(hexString), "0") & hexString
  End If
  Do While (Len(hexString) Mod 2) = 1
    hexString = "0" & hexString
  Loop
  For i = Len(hexString) To 2 Step -2
    temp = temp & Mid$(hexString, i - 1, 2)
  Next i
  writeHexR = temp

End Function

Public Function getBinaryString(fileHandle As Integer, Optional padLength As Integer) As String
  Dim i As Integer
  Dim chrData As Byte
  Do
    Get #fileHandle, , chrData
    If chrData = 0 Then Exit Do
    getBinaryString = getBinaryString & Chr$(chrData)
  Loop Until EOF(fileHandle)

  If Len(getBinaryString) < padLength Then
    For i = 1 To (padLength - Len(getBinaryString)) - 1
      Get #fileHandle, , chrData
    Next
  End If

End Function


Public Function printHex(inputString As String) As String
  Dim i As Integer
  For i = 1 To Len(inputString)
    printHex = printHex & Format(Asc(Mid$(inputString, i, 1)), "@@@") & ","
  Next
End Function

Public Sub printWords(inputString As String)

  ' Prints out debug information giving word numbers and information
  ' Useful for debugging

  Dim i As Integer
  Dim numWords As Integer
  Dim text As String
  
  numWords = countTokens(inputString, " ")
  For i = 1 To numWords
    If getWord(inputString, i) <> "" Then text = text & i & ": " & getWord(inputString, i) & " "
  Next i
  Debug.Print text
End Sub
